# Least Squares Filters

Least Squares filters provide an alternative approach to estimation that minimizes the sum of squared errors.

## Overview

Least squares estimation finds the parameters that minimize the sum of the squared differences between observed and predicted values. This technique is foundational to many filtering approaches.

## API Reference

For detailed API documentation, see the [Least Squares API reference](../api/leastsq.md).

## Further Reading

For comprehensive examples and theory, see the companion book:
[Kalman and Bayesian Filters in Python](https://github.com/rlabbe/Kalman-and-Bayesian-Filters-in-Python/)
